@@ -270,7 +270,7 @@ class SendMediaGroup(TgMethod):
     """ https://core.telegram.org/bots/api#sendmediagroup """
 
     chat_id: int | str
-    media: list[InputMediaAudio, InputMediaDocument, InputMediaPhoto, InputMediaVideo]
+    media: list[InputMediaAudio | InputMediaDocument | InputMediaPhoto | InputMediaVideo]
     disable_notification: bool = None
     protect_content: bool = None
     reply_to_message_id: int = None
